==> php3_3.0.orig.tar.gz: php-3.0/functions/php3_browscap.h <==
/* 
   +----------------------------------------------------------------------+
   | PHP HTML Embedded Scripting Language Version 3.0                     |
   +----------------------------------------------------------------------+
   | Copyright (c) 1997,1998 PHP Development Team (See Credits file)      |
   +----------------------------------------------------------------------+
   | This program is free software; you can redistribute it and/or modify |
   | it under the terms of one of the following licenses:                 |
   |                                                                      |
   |  A) the GNU General Public License as published by the Free Software |
   |     Foundation; either version 2 of the License, or (at your option) |
   |     any later version.                                               |
   |                                                                      |
   |  B) the PHP License as published by the PHP Development Team and     |
   |     included in the distribution in the file: LICENSE                |
   |                                                                      |
   | This program is distributed in the hope that it will be useful,      |
   | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
   | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
   | GNU General Public License for more details.                         |
   |                                                                      |
   | You should have received a copy of both licenses referred to here.   |
   | If you did not, or have any questions about PHP licensing, please    |
   | contact core@php.net.                                                |
   +----------------------------------------------------------------------+
   | Authors: Zeev Suraski <bourbon@netvision.net.il>                     |
   +----------------------------------------------------------------------+
 */


#ifndef _PHP3_BROWSCAP_H
#define _PHP3_BROWSCAP_H

extern php3_module_entry browscap_module_entry;
#define browscap_module_ptr &browscap_module_entry

extern int php3_minit_browscap(INIT_FUNC_ARGS);
extern int php3_mshutdown_browscap(void);

extern void php3_get_browser(INTERNAL_FUNCTION_PARAMETERS);


#endif /* _PHP3_BROWSCAP_H */

==> php3_3.0.18.orig.tar.gz: php3-3.0.18/functions/php3_browscap.h <==
/* 
   +----------------------------------------------------------------------+
   | PHP HTML Embedded Scripting Language Version 3.0                     |
   +----------------------------------------------------------------------+
   | Copyright (c) 1997-2000 PHP Development Team (See Credits file)      |
   +----------------------------------------------------------------------+
   | This program is free software; you can redistribute it and/or modify |
   | it under the terms of one of the following licenses:                 |
   |                                                                      |
   |  A) the GNU General Public License as published by the Free Software |
   |     Foundation; either version 2 of the License, or (at your option) |
   |     any later version.                                               |
   |                                                                      |
   |  B) the PHP License as published by the PHP Development Team and     |
   |     included in the distribution in the file: LICENSE                |
   |                                                                      |
   | This program is distributed in the hope that it will be useful,      |
   | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
   | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
   | GNU General Public License for more details.                         |
   |                                                                      |
   | You should have received a copy of both licenses referred to here.   |
   | If you did not, or have any questions about PHP licensing, please    |
   | contact core@php.net.                                                |
   +----------------------------------------------------------------------+
   | Authors: Zeev Suraski <zeev@zend.com>                                |
   +----------------------------------------------------------------------+
 */

/* $Id: php3_browscap.h,v 1.12 2000/02/07 23:54:51 zeev Exp $ */

#ifndef _PHP3_BROWSCAP_H
#define _PHP3_BROWSCAP_H

extern php3_module_entry browscap_module_entry;
#define browscap_module_ptr &browscap_module_entry

extern int php3_minit_browscap(INIT_FUNC_ARGS);
extern int php3_mshutdown_browscap(void);

extern void php3_get_browser(INTERNAL_FUNCTION_PARAMETERS);


#endif /* _PHP3_BROWSCAP_H */
